@@ -132,14 +132,21 @@ callback (buffer_info * buffer, NuDCLRef dcl)
     if (buffer->status != BUFFER_EMPTY)
         dc1394_log_error("buffer %d should have been empty",buffer->i);
 
-#if 0
+    /*
+     * We do this Notify() here in order to run the "update" step on the
+     * NuDCL program.  This is done instead of AppendDCLUpdateList() because
+     * that function does not work properly on Mac OS 10.4, as explained
+     * here:
+     *   http://lists.apple.com/archives/Firewire/2006/Aug/msg00002.html
+     *
+     * Also, the Notify() can only handle 30 DCLs at a time.
+     */
     for (i = 0; i < buffer->num_dcls; i += 30) {
         (*capture->loc_port)->Notify (capture->loc_port,
                                       kFWNuDCLUpdateNotification,
                                       (void **) buffer->dcl_list + i,
                                       MIN (buffer->num_dcls - i, 30));
     }
-#endif
 
     for (i = 0; i < buffer->num_dcls; i++) {
         int packet_size = capture->frames[buffer->i].packet_size;
@@ -276,8 +283,10 @@ CreateDCLProgram (platform_camera_t * craw)
             buffer->dcl_list[j] = dcl;
         }
 
+#if 0
         for (j = 0; j < ppf; j++)
             (*dcl_pool)->AppendDCLUpdateList (dcl, buffer->dcl_list[j]);
+#endif
         (*dcl_pool)->SetDCLRefcon (dcl, capture->buffers + i);
         (*dcl_pool)->SetDCLCallback (dcl, (NuDCLCallback) callback);
     }
@@ -312,12 +321,13 @@ servicing_thread (void * cam_ptr)
  CAPTURE SETUP
 **************************************************************/
 dc1394error_t
-platform_capture_setup(platform_camera_t *craw, uint32_t num_dma_buffers,
+dc1394_macosx_capture_setup(platform_camera_t *craw, uint32_t num_dma_buffers,
                      uint32_t flags)
 {
     dc1394capture_t * capture = &(craw->capture);
     dc1394camera_t * camera = craw->camera;
     dc1394error_t err;
+    IOReturn ret;
     IOFireWireLibDeviceRef d = craw->iface;
     IOFWSpeed speed;
     IOFireWireLibIsochChannelRef chan;
@@ -397,7 +407,7 @@ platform_capture_setup(platform_camera_t *craw, uint32_t num_dma_buffers,
                                      capture->frames[0].packet_size, speed,
                                      CFUUIDGetUUIDBytes (kIOFireWireIsochChannelInterfaceID));
     if (!chan) {
-        platform_capture_stop (craw);
+        dc1394_macosx_capture_stop (craw);
         dc1394_log_error("Could not create IsochChannelInterface");
         return DC1394_FAILURE;
     }
@@ -406,7 +416,7 @@ platform_capture_setup(platform_camera_t *craw, uint32_t num_dma_buffers,
     rem_port = (*d)->CreateRemoteIsochPort (d, true,
                                             CFUUIDGetUUIDBytes (kIOFireWireRemoteIsochPortInterfaceID));
     if (!rem_port) {
-        platform_capture_stop (craw);
+        dc1394_macosx_capture_stop (craw);
         dc1394_log_error("Could not create RemoteIsochPortInterface");
         return DC1394_FAILURE;
     }
@@ -426,7 +436,7 @@ platform_capture_setup(platform_camera_t *craw, uint32_t num_dma_buffers,
     dcl_pool = (*d)->CreateNuDCLPool (d, numdcls,
                                       CFUUIDGetUUIDBytes (kIOFireWireNuDCLPoolInterfaceID));
     if (!dcl_pool) {
-        platform_capture_stop (craw);
+        dc1394_macosx_capture_stop (craw);
         dc1394_log_error("Could not create NuDCLPoolInterface");
         return DC1394_FAILURE;
     }
@@ -434,7 +444,7 @@ platform_capture_setup(platform_camera_t *craw, uint32_t num_dma_buffers,
 
     dcl_program = CreateDCLProgram (craw);
     if (!dcl_program) {
-        platform_capture_stop (craw);
+        dc1394_macosx_capture_stop (craw);
         dc1394_log_error("Could not create DCL Program");
         return DC1394_FAILURE;
     }
@@ -443,7 +453,7 @@ platform_capture_setup(platform_camera_t *craw, uint32_t num_dma_buffers,
                                            kFWDCLSyBitsEvent, 1, 1, nil, 0, &(capture->databuf), 1,
                                            CFUUIDGetUUIDBytes (kIOFireWireLocalIsochPortInterfaceID));
     if (!loc_port) {
-        platform_capture_stop (craw);
+        dc1394_macosx_capture_stop (craw);
         dc1394_log_error("Could not create LocalIsochPortInterface");
         return DC1394_FAILURE;
     }
@@ -456,15 +466,19 @@ platform_capture_setup(platform_camera_t *craw, uint32_t num_dma_buffers,
     (*chan)->AddListener (chan, (IOFireWireLibIsochPortRef) loc_port);
     (*chan)->SetTalker (chan, (IOFireWireLibIsochPortRef) rem_port);
 
-    if ((*chan)->AllocateChannel (chan) != kIOReturnSuccess) {
-        platform_capture_stop (craw);
-        dc1394_log_error("Could not allocate channel");
+    if ((ret = (*chan)->AllocateChannel (chan)) != kIOReturnSuccess) {
+        dc1394_macosx_capture_stop (craw);
+        if (ret == kIOReturnNoSpace)
+            dc1394_log_error("Not enough iso bandwidth or channels are "
+                    "available to begin capture");
+        else
+            dc1394_log_error("Could not allocate channel");
         return DC1394_FAILURE;
     }
     capture->iso_is_allocated = 1;
 
     if ((*chan)->Start (chan) != kIOReturnSuccess) {
-        platform_capture_stop (craw);
+        dc1394_macosx_capture_stop (craw);
         dc1394_log_error("Could not start channel");
         return DC1394_FAILURE;
     }
@@ -488,7 +502,7 @@ platform_capture_setup(platform_camera_t *craw, uint32_t num_dma_buffers,
 *****************************************************/
 
 dc1394error_t
-platform_capture_stop(platform_camera_t *craw)
+dc1394_macosx_capture_stop(platform_camera_t *craw)
 {
     dc1394camera_t * camera = craw->camera;
     dc1394capture_t * capture = &(craw->capture);
@@ -590,7 +604,7 @@ platform_capture_stop(platform_camera_t *craw)
 //#define PREV_BUFFER(c,i) (((i) == 0) ? (c)->num_frames-1 : ((i)-1))
 
 dc1394error_t
-platform_capture_dequeue (platform_camera_t * craw,
+dc1394_macosx_capture_dequeue (platform_camera_t * craw,
                         dc1394capture_policy_t policy,
                         dc1394video_frame_t **frame)
 {
@@ -639,7 +653,7 @@ platform_capture_dequeue (platform_camera_t * craw,
 
 
 dc1394error_t
-platform_capture_enqueue (platform_camera_t * craw,
+dc1394_macosx_capture_enqueue (platform_camera_t * craw,
                         dc1394video_frame_t * frame)
 {
     dc1394capture_t * capture = &(craw->capture);
@@ -683,7 +697,7 @@ platform_capture_enqueue (platform_camera_t * craw,
 }
 
 dc1394bool_t
-platform_capture_is_frame_corrupt (platform_camera_t * craw,
+dc1394_macosx_capture_is_frame_corrupt (platform_camera_t * craw,
         dc1394video_frame_t * frame)
 {
     dc1394capture_t * capture = &(craw->capture);
@@ -696,7 +710,7 @@ platform_capture_is_frame_corrupt (platform_camera_t * craw,
 }
 
 int
-platform_capture_get_fileno (platform_camera_t * craw)
+dc1394_macosx_capture_get_fileno (platform_camera_t * craw)
 {
     dc1394capture_t * capture = &(craw->capture);
 
