@@ -23,10 +23,6 @@
 #ifndef __DC1394_CAPTURE_MACOSX_H__
 #define __DC1394_CAPTURE_MACOSX_H__
 
-#ifdef __cplusplus
-extern "C" {
-#endif 
-
 typedef void (*dc1394capture_callback_t)(dc1394camera_t *, void *);
 
 int
@@ -36,8 +32,4 @@ void
 dc1394_capture_set_callback (dc1394camera_t * camera,
         dc1394capture_callback_t callback, void * user_data);
 
-#ifdef __cplusplus
-}
-#endif 
-
 #endif
