@@ -69,20 +69,9 @@ static struct _vendor_product_t {
 } usb_products[] = {
     { 0x1e10, 0x2000 }, // Point Grey Firefly MV Color
     { 0x1e10, 0x2001 }, // Point Grey Firefly MV Mono
-    { 0x1e10, 0x2002 }, // Point Grey High Res Firefly MV Color
-    { 0x1e10, 0x2003 }, // Point Grey High Res Firefly MV Mono
     { 0x1e10, 0x2004 }, // Point Grey Chameleon Color
     { 0x1e10, 0x2005 }, // Point Grey Chameleon Mono
-    { 0x1e10, 0x3000 }, // Point Grey Flea 3
-    { 0x1e10, 0x3005 }, // Point Grey Flea 3 (FL3-U3-13Y3M)
-    { 0x1e10, 0x3006 }, // Point Grey Flea 3 (FL3-U3-13S2C)
-    { 0x1e10, 0x3008 }, // Point Grey Flea 3 (FL3-U3-88S2C)
-    { 0x1e10, 0x300a }, // Point Grey Flea 3 (FL3-U3-13E4C)
-    { 0x1e10, 0x300b }, // Point Grey Flea 3 (FL3-U3-13E4M with 1.43.3.2 FW)
-    { 0x1e10, 0x3103 }, // Point Grey Grasshopper 3 (GS3-U3-23S6M)
-    { 0x1e10, 0x3300 }, // Point Grey Flea 3 (FL3-U3-13E4M with 2.7.3.0 FW)
-	{ 0x1e10, 0x3800 }, // Point Grey Ladybug 5 (LD5-U3-51S5C-44)
-    { 0, 0 }
+    { 0, 0 },
 };
 
 static int
@@ -211,10 +200,10 @@ do_write (libusb_device_handle * handle, uint64_t address,
     int i;
     /* Convert from host-endian to little-endian */
     for (i = 0; i < num_quads; i++) {
-        buf[4*i]   = quads[i] & 0xff;
-        buf[4*i+1] = (quads[i] >> 8) & 0xff;
-        buf[4*i+2] = (quads[i] >> 16) & 0xff;
-        buf[4*i+3] = (quads[i] >> 24) & 0xff;
+        buf[4*i]   = quads[0] & 0xff;
+        buf[4*i+1] = (quads[0] >> 8) & 0xff;
+        buf[4*i+2] = (quads[0] >> 16) & 0xff;
+        buf[4*i+3] = (quads[0] >> 24) & 0xff;
     }
     /* IEEE 1394 address writes are mapped to USB control transfers as
      * shown here. */
@@ -386,18 +375,10 @@ usb_dispatch = {
     .capture_enqueue = dc1394_usb_capture_enqueue,
     .capture_get_fileno = dc1394_usb_capture_get_fileno,
     .capture_is_frame_corrupt = dc1394_usb_capture_is_frame_corrupt,
-
-#ifdef HAVE_MACOSX
-    .capture_set_callback = dc1394_usb_capture_set_callback,
-    .capture_schedule_with_runloop = dc1394_usb_capture_schedule_with_runloop,
-#else
-    .capture_set_callback = NULL,
-    .capture_schedule_with_runloop = NULL,
-#endif
 };
 
 void
-dc1394_usb_init(dc1394_t * d)
+usb_init(dc1394_t * d)
 {
     register_platform (d, &usb_dispatch, "usb");
 }
